@@ -16,11 +16,15 @@ def execute_request(
     file: Union[str, None] = None,
 ) -> Any:
   verified_credentials = verify_credentials(credentials)
+  headers = {
+      "Authorization": f"Bearer {verified_credentials.token}",
+      "X-Tim-Client": verified_credentials.clientName,
+  }
 
   upload_file = lambda: requests.request(
       method=method,
       url=f"{verified_credentials.endpoint}{path}",
-      headers={"Authorization": f"Bearer {verified_credentials.token}"},
+      headers=headers,
       files={
           "configuration": json.dumps(body),
           "file": file,
@@ -32,7 +36,7 @@ def execute_request(
       url=f"{verified_credentials.endpoint}{path}",
       json=body,
       params=params,
-      headers={"Authorization": f"Bearer {verified_credentials.token}"},
+      headers=headers,
   )
 
   response = upload_file() if file else handle_request()
