@@ -1,7 +1,7 @@
 from enum import Enum
 from typing import NamedTuple, Optional, Union, List
 from typing_extensions import TypedDict
-from tim.types import Logs, Status
+from tim.types import Logs, Id
 
 
 class BaseUnit(Enum):
@@ -12,6 +12,20 @@ class BaseUnit(Enum):
   MONTH = 'Month'
 
 
+class Status(Enum):
+  REGISTERED = 'Registered'
+  RUNNING = 'Running'
+  FINISHED = 'Finished'
+  FINISHED_WITH_WARNING = 'FinishedWithWarning'
+  FAILED = 'Failed'
+
+
+class DatasetStatusResponse(TypedDict):
+  createdAt: str
+  status: Status
+  progress: int
+
+
 class RelativeRange(TypedDict):
   baseUnit: BaseUnit
   value: int
@@ -80,10 +94,6 @@ class CSVSeparator(Enum):
   COMMA = ','
 
 
-class Workspace(TypedDict):
-  id: str
-
-
 class UploadCSVConfiguration(TypedDict, total=False):
   timestampFormat: str
   timestampColumn: Union[str, int]
@@ -91,7 +101,7 @@ class UploadCSVConfiguration(TypedDict, total=False):
   name: str
   description: str
   samplingPeriod: RelativeRange
-  workspace: Workspace
+  workspace: Id
 
 
 class UploadCSVVersion(TypedDict):
